@@ -8,66 +8,67 @@ import epw
 import pv
 import json
 
-def tools_fill(inverter, zipcode, acDcRatio = 1.2, mount="Roof", stationClass = 1, Vmax = 600, bipolar= True):
-    #deprecated legacy function
-    return [format(i) for i in fill(**locals())]
+def tools_fill(inverter, zipcode, ac_dc_ratio=1.2, mount="Roof", \
+        station_class=1, v_max=600, bipolar=True):
+    """deprecated legacy function"""
+    return [str_format(i) for i in fill(**locals())]
 
-def format(inverter):
-    """'9769.5W : 13S x 3P : ratio 1.22 : 314.0 - 552.0 V'"""
+def str_format(inverter):
+    """format as str: '9769.5W : 13S x 3P : ratio 1.22 : 314.0 - 552.0 V'"""
     DC = inverter.array.output(1000)
-    ratio = DC/inverter.Paco
+    ratio = DC/inverter.p_aco
     return '%sW : %s : ratio %s : %s - %s V' % (DC, inverter.array, \
-            round(ratio,2), round(inverter.minV), round(inverter.maxV))
+            round(ratio, 2), round(inverter.minV), round(inverter.maxV))
 
-def fill(inverter, zipcode, acDcRatio = 1.2, mount="Roof", stationClass = 1, \
-        Vmax = 600, bipolar= True):
-    import geo
+def fill(inverter, zipcode, ac_dc_ratio=1.2, mount="Roof", station_class=1, \
+        v_max=600, bipolar=True):
     """String sizing"""
+    import geo
     tDerate = {"Roof":30,
             "Ground":25,
             "Pole":20}
 
     #csv is performance hit
-    name, usaf = geo.closestUSAF( geo.zipToCoordinates(zipcode), stationClass)
-    maxV = inverter.array.panel.Vmax(epw.minimum(usaf))
+    name, usaf = geo.closest_usaf(geo.zip_coordinates(zipcode), station_class)
+    maxV = inverter.array.panel.v_max(epw.minimum(usaf))
     #NREL suggests that long term degradation is primarily current not voltage
     derate20 = .97
-    minV = inverter.array.panel.Vmin(epw.twopercent(usaf),tDerate[mount]) * \
+    minV = inverter.array.panel.v_min(epw.twopercent(usaf), tDerate[mount]) * \
             derate20
 
     if inverter.vdcmax != 0:
-         Vmax = inverter.vdcmax
-    smax = int(Vmax/maxV)
+        v_max = inverter.vdcmax
+    smax = int(v_max/maxV)
     #range to search
-    pTol = .30
-    inverterNominal = inverter.Paco
-    psize = inverter.array.panel.Pmax
+    p_tol = .30
+    inverter_nominal = inverter.p_aco
+    psize = inverter.array.panel.p_max
     solutions = []
 
-    Imax = max(inverter.idcmax,inverter.Pdco*1.0/inverter.mppt_low)
-    stringMax = int(round(Imax/inverter.array.panel.Impp))+1
+    i_max = max(inverter.idcmax, inverter.p_dco*1.0/inverter.mppt_low)
+    stringMax = int(round(i_max/inverter.array.panel.i_mpp))+1
 
     #Diophantine equation
     for s in range(smax+1):
         if (s*minV) >= inverter.mppt_low:
             for p in range(stringMax):
-                pRatio = p*s*psize*1.0/inverterNominal
-                if pRatio < (acDcRatio*(1+pTol)) and \
-                        pRatio > (acDcRatio*(1-pTol)):
-                            inverter.array.shape = [s]*p
-                            t = copy.deepcopy(inverter)
-                            t.minV = s*minV
-                            t.maxV = s*maxV
-                            solutions.append(t)
+                pRatio = p*s*psize*1.0/inverter_nominal
+                if pRatio < (ac_dc_ratio*(1+p_tol)) and \
+                        pRatio > (ac_dc_ratio*(1-p_tol)):
+                    inverter.array.shape = [s]*p
+                    t = copy.deepcopy(inverter)
+                    t.minV = s*minV
+                    t.maxV = s*maxV
+                    solutions.append(t)
     return solutions
 
-def generateOptions(inverterName,moduleName,zipcode, channels=1, acDcRatio = 1.2, \
-        mount="Roof", stationClass = 1, Vmax = 600, bipolar= True):
+def generate_options(inverterName, moduleName, zipcode, \
+        ac_dc_ratio=1.2, mount="Roof", station_class=1, v_max=600, bipolar=True):
     import geo
     import inverters
     import modules
-    module = modules.module(moduleName)
-    inverter = inverters.inverter(inverterName)
+    module = modules.Module(moduleName)
+    inverter = inverters.Inverter(inverterName)
     """String sizing"""
     tempAdder = {"Roof":30,
             "Ground":25,
@@ -76,41 +77,49 @@ def generateOptions(inverterName,moduleName,zipcode, channels=1, acDcRatio = 1.2
     derate20 = .97
 
     #csv is performance hit
-    name, usaf = geo.closestUSAF( geo.zipToCoordinates(zipcode), stationClass)
+    name, usaf = geo.closest_usaf(geo.zip_coordinates(zipcode), station_class)
     epw_min = epw.minimum(usaf)
-    moduleMaxVoltage = module.Vmax(epw_min)
+    moduleMaxVoltage = module.v_max(epw_min)
     epw2 = epw.twopercent(usaf)
-    moduleMinVoltage = module.Vmin(epw2,tempAdder[mount]) * derate20
+    moduleMinVoltage = module.v_min(epw2, tempAdder[mount]) * derate20
 
     if inverter.vdcmax != 0:
-         Vmax = inverter.vdcmax
-    maxlen = int(Vmax/moduleMaxVoltage)
+        v_max = inverter.vdcmax
+    maxlen = int(v_max//moduleMaxVoltage)
     minlen = int(inverter.mppt_low/moduleMinVoltage) + 1
-    inverter.array = modules.array(module,[{'series':minlen}]*inverter.mppt_channels)
+    if minlen > maxlen:
+        return []
+    inverter.array = modules.Array(module, \
+            [{'series':minlen}]*inverter.mppt_channels)
     inverter.array.minlength(minlen)
     inverter.array.maxlength(maxlen)
     #range to search
-    pTol = .30
-    inverterNominal = inverter.Paco
+    p_tol = .30
+    inverter_nominal = inverter.p_aco
     solutions = []
-    while (inverter.array.output(1000) < inverterNominal * (acDcRatio + pTol)):
+    while inverter.array.output(1000) < inverter_nominal * (ac_dc_ratio + p_tol):
         inverter.array.inc()
-        print inverter.array
-        print inverter.array.output(1000),inverter.ratio()
+        #print inverter.array
+        #print inverter.array.output(1000), inverter.ratio()
         t = copy.deepcopy(inverter)
-        t.maxV = t.array.Vmax(epw_min)
-        t.minV = t.array.Vmin(epw2,tempAdder[mount])
-        solutions.append(t)
+        t.maxV = t.array.v_max(epw_min)
+        t.minV = t.array.v_min(epw2, tempAdder[mount])
+        #print inverter.ratio()
+        if inverter.ratio() > ac_dc_ratio*(1. - p_tol):
+            solutions.append(t)
     return solutions
 
-    #Imax = max(inverter.idcmax,inverter.Pdco*1.0/inverter.mppt_low)
-    #stringMax = int(round(Imax/inverter.array.panel.Impp))+1
+    #i_max = max(inverter.idcmax,inverter.p_dco*1.0/inverter.mppt_low)
+    #stringMax = int(round(i_max/inverter.array.panel.i_mpp))+1
 
     #Diophantine equation
     return solutions
 
 def knapsack(items, maxweight):
-    #http://codereview.stackexchange.com/questions/20569/dynamic-programming-solution-to-knapsack-problem
+    """knapsack problem weight is system DC size and value is annual output
+    this could be expanded with different constraints for different rankings"""
+    #http://codereview.stackexchange.com/questions/20569/
+    #dynamic-programming-solution-to-knapsack-problem
     bestvalues = [[0] * (maxweight + 1)
                   for i in xrange(len(items) + 1)]
     for i, (value, weight, systemDict) in enumerate(items):
@@ -133,34 +142,42 @@ def knapsack(items, maxweight):
         i -= 1
 
     reconstruction.reverse()
-    systemSet = [subA for v,w,subA in reconstruction]
+    system_set = [subA for v, w, subA in reconstruction]
 
-    return bestvalues[len(items)][maxweight], systemSet
+    results = {'algorithm':'knapsack',
+            'notes':'most annual generation',
+            'system_weight':bestvalues[len(items)][maxweight], 
+            'system_set': system_set}
+    return results
 
 def efficient(items, maxweight):
     """symetric design of the most efficeint inverter panel combo"""
-    mostEff = [None, None, None]
-    for (value, weight, systemDict) in items:
+    most_eff = [None, None, None]
+    for (value, weight, system_dict) in items:
         eff = value/float(weight)
-        if eff > mostEff[0]:
-            mostEff = [eff,weight,systemDict]
-    scale = maxweight/mostEff[1]
-    result = [mostEff[2]]*scale
-    return (mostEff[1]*scale, result)
+        if eff > most_eff[0]:
+            most_eff = [eff, weight, system_dict]
+    scale = maxweight/most_eff[1]
+    system_result = [most_eff[2]]*scale
+    results = {'algorithm':'efficient',
+            'notes':'symetric design of most efficient combination',
+            'system_weight':most_eff[1]*scale,
+            'system_set': system_result}
+    return results
 
-def combinations(a,b):
+def combinations(a, b):
     s = []
     for i in a:
         for j in b:
-            s.append((i,j))
+            s.append((i, j))
     return s
 
 def performanceModelPlant(jsonDef):
-    plant = pv.jsonToSystem(jsonDef)
+    plant = pv.json_system(jsonDef)
     yearone = plant.model()
     PDC = sum([i.array.output(1000) for i in plant.shape])
     plantDict = plant.dump()
-    plantDict['yearone'] = yearone.annualOutput
+    plantDict['yearone'] = yearone.annual_output
     plantDict['DCnominal'] = int(PDC)
     return plantDict
 
@@ -171,11 +188,11 @@ def performanceModelSet(clist):
         from celery import group
         import pmodel
         #print CSTAT
-        return group(pmodel.modelPlant.s(i) for i in clist)().get()
+        return group(pmodel.model_plant.s(i) for i in clist)().get()
     else:
         return [performanceModelPlant(pJSON) for pJSON in clist]
 
-def design(reqsStr):
+def design(reqsStr,ranking=[efficient,knapsack]):
     """parts selection algorithm. """
     reqs = json.loads(reqsStr)
     validC = []
@@ -184,12 +201,12 @@ def design(reqsStr):
 
     for inverterModel, panelModel in combinations(reqs['inverter options'],\
             reqs['panel options']):
-        system = inverters.inverter(inverterModel,\
-                modules.pvArray(modules.module(panelModel),[2]))
-        configs = fill(system,zc)
+        #system = inverters.Inverter(inverterModel,\
+        #        modules.PvArray(modules.Module(panelModel), [{'series':2}]))
+        configs = generate_options(inverterModel, panelModel, zc)
         for config in configs:
             validC.append(config)
-            print config, config.array, config.array.panel, \
+            print config, '\n',config.array, config.array.dump()['panel'], \
                     config.array.output(1000), config.ratio()
 
             reqs['array'] = [config.dump()]
@@ -197,25 +214,18 @@ def design(reqsStr):
 
     performanceResults = performanceModelSet(optionSet)
 
-    configSet= []
+    configSet = []
     for o in performanceResults:
         #hack to expand for semetery
         scale = reqs['desired size'] // o['DCnominal']
-        configSet += [(o['yearone'],o['DCnominal'],o['array'][0])] * scale
+        configSet += [(o['yearone'], o['DCnominal'], o['array'][0])] * scale
 
     suggested = []
-
-    #knapsack problem weight is system DC size and value is annual output
-    #this could be expanded with different constraints for different rankings
-    systemWeight, systemSet = knapsack(configSet, reqs['desired size'])
-    reqs['array'] = systemSet 
-    reqs['notes'] = 'Maximum size'
-    suggested.append(copy.deepcopy(reqs))
-
-    systemWeight, systemSet = efficient(configSet, reqs['desired size'])
-    reqs['array'] = systemSet
-    reqs['notes'] = 'Maximum symetric efficiency'
-    suggested.append(copy.deepcopy(reqs))
+    for algo in ranking:
+        proposed = algo(configSet, reqs['desired size'])
+        reqs['array'] = proposed['system_set']
+        reqs['algorithm'] = proposed['algorithm']
+        suggested.append(copy.deepcopy(reqs))
 
     return suggested
 
@@ -226,15 +236,15 @@ def celery_worker_status():
         insp = inspect()
         d = insp.stats()
         if not d:
-            d = { ERROR_KEY: 'No running Celery workers were found.' }
+            d = {ERROR_KEY: 'No running Celery workers were found.'}
     except IOError as e:
         from errno import errorcode
         msg = "Error connecting to the backend: " + str(e)
         if len(e.args) > 0 and errorcode.get(e.args[0]) == 'ECONNREFUSED':
             msg += ' Check that the RabbitMQ server is running.'
-        d = { ERROR_KEY: msg }
+        d = {ERROR_KEY: msg}
     except ImportError as e:
-        d = { ERROR_KEY: str(e)}
+        d = {ERROR_KEY: str(e)}
     return d
 
 if __name__ == "__main__":
@@ -324,11 +334,11 @@ if __name__ == "__main__":
             testreqs = open(args['file']).read()
 
         for proposed in design(testreqs):
-            proposedPlant = pv.jsonToSystem(proposed)
+            proposedPlant = pv.json_system(proposed)
             print json.dumps(proposedPlant.dump(), sort_keys=True, indent=4, \
                 separators=(',', ': '))
-            print proposed['notes']
-            expedite.string_notes(proposedPlant)
+            print proposed['algorithm']
+            expedite.string_notes(proposedPlant,1)
 
     except (KeyboardInterrupt, SystemExit):
         sys.exit(1)
